@@ -1,5 +1,5 @@
 #!/usr/bin/env python
 # pylint: skip-file
-from mi_graph import cli
+from mi_graph.util import cli
 
 cli()
